@@ -11,7 +11,7 @@ use Form::Tiny::Form;
 use Form::Tiny::Utils qw(trim :meta_handlers);
 require Moo;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 sub import
 {
@@ -23,11 +23,11 @@ sub import
 	@wanted = (-base, grep { $_ ne -base } @wanted);
 
 	# very special case - do something UNLESS -nomoo was passed
-	unless (_get_flag(\@wanted, -nomoo)) {
+	unless ($package->_get_flag(\@wanted, -nomoo)) {
 		Moo->import::into($caller);
 	}
 
-	ft_install($caller, @wanted);
+	$package->ft_install($caller, @wanted);
 	namespace::clean->import(
 		-cleanee => $caller,
 		-except => 'form_meta'
@@ -38,7 +38,7 @@ sub import
 
 sub ft_install
 {
-	my ($caller, @import_flags) = @_;
+	my ($self, $caller, @import_flags) = @_;
 
 	my $context;
 	my $wanted = {
@@ -47,9 +47,12 @@ sub ft_install
 		meta_roles => [],
 	};
 
-	my $plugins = _get_flag(\@import_flags, 'plugins', 1);
+	my $plugins = $self->_get_flag(\@import_flags, 'plugins', 1);
 
-	_select_behaviors($wanted, \@import_flags, _get_behaviors(_generate_helpers($caller, \$context)));
+	$self->_select_behaviors(
+		$wanted, \@import_flags,
+		$self->_get_behaviors($self->_generate_helpers($caller, \$context))
+	);
 
 	foreach my $plugin (@$plugins) {
 		$plugin = "Form::Tiny::Plugin::$plugin";
@@ -61,7 +64,7 @@ sub ft_install
 		croak "$plugin is not a Form::Tiny::Plugin"
 			unless $plugin->isa('Form::Tiny::Plugin');
 
-		_select_behaviors($wanted, [$plugin], {$plugin => $plugin->plugin($caller, \$context)});
+		$self->_select_behaviors($wanted, [$plugin], {$plugin => $plugin->plugin($caller, \$context)});
 	}
 
 	# create metapackage with roles
@@ -85,7 +88,7 @@ sub ft_install
 
 sub _generate_helpers
 {
-	my ($caller, $field_context) = @_;
+	my ($self, $caller, $field_context) = @_;
 
 	my $use_context = sub {
 		croak 'context using DSL keyword called without context'
@@ -132,7 +135,7 @@ sub _generate_helpers
 
 sub _get_behaviors
 {
-	my ($subs) = @_;
+	my ($self, $subs) = @_;
 
 	return {
 		-base => {
@@ -167,7 +170,7 @@ sub _get_behaviors
 
 sub _select_behaviors
 {
-	my ($wanted, $types, $behaviors) = @_;
+	my ($self, $wanted, $types, $behaviors) = @_;
 
 	foreach my $type (@$types) {
 		croak "no Form::Tiny import behavior for: $type"
@@ -181,7 +184,7 @@ sub _select_behaviors
 
 sub _get_flag
 {
-	my ($flags, $wanted, $with_param) = @_;
+	my ($self, $flags, $wanted, $with_param) = @_;
 	$with_param //= 0;
 
 	for my $n (0 .. $#$flags) {
