@@ -12,14 +12,13 @@ use Form::Tiny::Utils qw(trim create_anon_form_meta);
 
 use namespace::clean;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 with 'Form::Tiny::Form';
 
 has '_meta' => (
 	is => 'ro',
 	isa => InstanceOf ['Form::Tiny::Meta'],
-	builder => '_build_meta',
 	init_arg => undef,
 	default => sub {
 		my ($self) = @_;
@@ -122,7 +121,7 @@ Form::Tiny::Inline - Form::Tiny without hassle
 
 	my $form = Form::Tiny::Inline->new(
 		field_defs => [
-			{name => "some_field"},
+			{name => 'some_field'},
 			...
 		],
 	);
@@ -137,5 +136,5 @@ Inline forms are designed to cover all the basic use cases, but they are not as
 
 When ran on a Form::Tiny::Inline class, it produces a new object that you can call C<< ->new >> on.
 
-	$inline_form_builder = Form::Tiny::Inline->is("Filtered", "Strict");
+	$inline_form_builder = Form::Tiny::Inline->is('Filtered', 'Strict');
 
