@@ -9,13 +9,13 @@ use Form::Tiny::Error;
 
 use Moo::Role;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 use constant {
-	MARKER_NONE => "",
-	MARKER_SKIP => "skip",
-	MARKER_ARRAY => "array",
-	MARKER_LEAF => "leaf",
+	MARKER_NONE => '',
+	MARKER_SKIP => 'skip',
+	MARKER_ARRAY => 'array',
+	MARKER_LEAF => 'leaf',
 };
 
 requires qw(setup);
