@@ -8,22 +8,22 @@ use Types::Standard qw(ArrayRef);
 
 use namespace::clean;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
-has "path" => (
-	is => "ro",
+has 'path' => (
+	is => 'ro',
 	isa => ArrayRef,
 	required => 1,
 );
 
-has "value" => (
-	is => "ro",
-	writer => "set_value",
+has 'value' => (
+	is => 'ro',
+	writer => 'set_value',
 );
 
 # Is this value here only to reproduce structure?
-has "structure" => (
-	is => "ro",
+has 'structure' => (
+	is => 'ro',
 	default => 0,
 );
 
